StringExt extension

on

Properties

isEmptyOrNull → bool

Available on String?, provided by the StringExt extension

Return true if the string this is null or empty
no setter
isNotEmptyOrNull → bool

Available on String?, provided by the StringExt extension

Return true if the string this is not null or empty
no setter

Methods

dial() → Future<bool>

Available on String?, provided by the StringExt extension

launch({bool? forceSafariVC, bool forceWebView = false, bool enableJavaScript = false, bool enableDomStorage = false, bool universalLinksOnly = false, Map<String, String> headers = const <String, String>{}, Brightness? statusBarBrightness, String? webOnlyWindowName}) → Future<bool>

Available on String?, provided by the StringExt extension

Parses the specified URL string and delegates handling of it to the underlying platform.
sendMail() → Future<bool>

Available on String?, provided by the StringExt extension

toDouble({double? defaultValue}) → double?

Available on String?, provided by the StringExt extension

Parse this string as an double literal and return its value.
toInt({int? defaultValue}) → int?

Available on String?, provided by the StringExt extension

Parse this string as a, possibly signed, integer literal and return its value.
validate(String pattern) → bool

Available on String?, provided by the StringExt extension

Returns whether the regular expression pattern has a match in this string.
validateEmail() → bool

Available on String?, provided by the StringExt extension

Returns whether this string is a valid email address