Tappable class

Inheritance
Available extensions

Constructors

Tappable({Key? key, Widget? child, GestureTapCallback? onTap, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel})
const

Properties

child → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDoubleTap → GestureTapCallback?
final
onLongPress → GestureTapCallback?
final
onTap → GestureTapCallback?
final
onTapCancel → GestureTapCallback?
final
onTapDown → GestureTapDownCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

center() → Widget

Available on Widget, provided by the WidgetExt extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TappableState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expand([dynamic flex = 1]) → Widget

Available on Widget, provided by the WidgetExt extension

flex([dynamic flex = 1, dynamic fit = FlexFit.loose]) → Widget

Available on Widget, provided by the WidgetExt extension

marginBottom([num factor = 2]) → Widget

Available on Widget, provided by the WidgetExt extension

marginLeft([num factor = 1]) → Widget

Available on Widget, provided by the WidgetExt extension

marginRight([num factor = 1]) → Widget

Available on Widget, provided by the WidgetExt extension

marginTop([num factor = 2]) → Widget

Available on Widget, provided by the WidgetExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padHorizontal([num factor = 3]) → Widget

Available on Widget, provided by the WidgetExt extension

padVertical([num factor = 1]) → Widget

Available on Widget, provided by the WidgetExt extension

roundedBorder([double radius = FludaX.x]) → Widget

Available on Widget, provided by the WidgetExt extension

spaceAround([num factor = 1]) → Widget

Available on Widget, provided by the WidgetExt extension

tappable({GestureTapCallback? onTap, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureTapDownCallback? onTapDown, GestureTapCancelCallback? onTapCancel}) → Widget

Available on Widget, provided by the WidgetExt extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
wrapHero(String tag) → Widget

Available on Widget, provided by the WidgetExt extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited