StringExt extension
- on
Properties
- isEmptyOrNull → bool
-
Available on String?, provided by the StringExt extension
Returntrueif the stringthisisnullor emptyno setter - isNotEmptyOrNull → bool
-
Available on String?, provided by the StringExt extension
Returntrueif the stringthisis notnullor emptyno setter
Methods
-
dial(
) → Future< bool> -
launch(
{bool? forceSafariVC, bool forceWebView = false, bool enableJavaScript = false, bool enableDomStorage = false, bool universalLinksOnly = false, Map< String, String> headers = const <String, String>{}, Brightness? statusBarBrightness, String? webOnlyWindowName}) → Future<bool> - Parses the specified URL string and delegates handling of it to the underlying platform.
-
sendMail(
) → Future< bool> -
toDouble(
{double? defaultValue}) → double? -
Available on String?, provided by the StringExt extension
Parsethisstring as an double literal and return its value. -
toInt(
{int? defaultValue}) → int? -
Available on String?, provided by the StringExt extension
Parsethisstring as a, possibly signed, integer literal and return its value. -
validate(
String pattern) → bool -
Available on String?, provided by the StringExt extension
Returns whether the regular expressionpatternhas a match inthisstring. -
validateEmail(
) → bool -
Available on String?, provided by the StringExt extension
Returns whetherthisstring is a valid email address